<?php
namespace Controller;

use Exception\CustomException;
use Util\InstanceProvider;
use Zeedhi\DevOps\Util\Utilities as DevOpsUtilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Util\Messages;
use Util\Utilities;


class CpWebService extends Simple
{
    /** @var \Service\Attachment $attachmentService */
    protected $attachmentService;

    public function __construct(\Service\CpWebService $webServiceService) {
        $this->webServiceService = $webServiceService;
    }

    public function saveCustomizationFilesFromWebService(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $emptyFields = '';
            $nrorg = !empty($row['NRORG']) ? $row['NRORG'] : $emptyFields.= 'NRORG, ';
            $cdlocaluso = !empty($row['CDLOCALUSO']) ? $row['CDLOCALUSO'] : $emptyFields.= 'CDLOCALUSO, ';
            $idlusoativ = !empty($row['IDLUSOATIV']) ? $row['IDLUSOATIV'] : 'S';
            $nrlicencauso = !empty($row['CDLOCALUSO']) ? Utilities::zeroLeftPadding($row['CDLOCALUSO'], 10) : null;
            $nmfantluso = !empty($row['NMFANTLUSO']) ? $row['NMFANTLUSO'] : $emptyFields.= 'NMFANTLUSO, ';
            $nmrazsocluso = !empty($row['NMRAZSOCLUSO']) ? $row['NMRAZSOCLUSO'] : $emptyFields.= 'NMRAZSOCLUSO, ';
            $idtpijurluso = !empty($row['IDTPIJURLUSO']) ? $row['IDTPIJURLUSO'] : $emptyFields.= 'IDTPIJURLUSO, ';
            $nrinsjurluso = !empty($row['NRINSJURLUSO']) ? $row['NRINSJURLUSO'] : $emptyFields.= 'NRINSJURLUSO, ';
            $nrinsestluso = !empty($row['NRINSESTLUSO']) ? $row['NRINSESTLUSO'] : $emptyFields.= 'NRINSESTLUSO, ';
            $nrinsmuniluso = !empty($row['NRINSMUNILUSO']) ? $row['NRINSMUNILUSO'] : $emptyFields.= 'NRINSMUNILUSO, ';
            $nmcontluso = !empty($row['NMCONTLUSO']) ? $row['NMCONTLUSO'] : $emptyFields.= 'NMCONTLUSO, ';
            $nmdeptoluso =!empty($row['NMDEPTOLUSO']) ? $row['NMDEPTOLUSO'] : $emptyFields.= 'NMDEPTOLUSO, ';
            $idfaturafilisep = empty($row['IDFATURAFILISEP']) ? 'N' : $row['IDFATURAFILISEP'];
            $dsendeluso = !empty($row['DSENDELUSO']) ? $row['DSENDELUSO'] : $emptyFields.= 'DSENDELUSO, ';
            $nmbairluso = !empty($row['NMBAIRLUSO']) ? $row['NMBAIRLUSO'] : $emptyFields.= 'NMBAIRLUSO, ';
            $nrcepluso = !empty($row['NRCEPLUSO']) ? $row['NRCEPLUSO'] : $emptyFields.= 'NRCEPLUSO, ';
            $cdpais = !empty($row['CDPAIS']) ? $row['CDPAIS'] : $emptyFields.= 'CDPAIS, ';
            $sgestado = !empty($row['SGESTADO']) ? $row['SGESTADO'] : $emptyFields.= 'SGESTADO, ';
            $cdmunicipio = !empty($row['CDMUNICIPIO']) ? $row['CDMUNICIPIO'] : $emptyFields.= 'CDMUNICIPIO, ';
            $nrteleluso = empty($row['NRTELELUSO']) ? null : $row['NRTELELUSO'];
            $nrramalluso = empty($row['NRRAMALLUSO']) ? null : $row['NRRAMALLUSO'];
            $nrfaxluso = empty($row['NRFAXLUSO']) ? null : $row['NRFAXLUSO'];
            $dsemailcomlu = empty($row['DSEMAILCOMLU']) ? null : $row['DSEMAILCOMLU'];
            $cdlinpclie = !empty($row['CDLINPCLIE']) ? $row['CDLINPCLIE'] : array();
            $idmodproc = empty($row['IDMODPROC']) ? 'F' : $row['IDMODPROC'];
            $idlocaproc = empty($row['IDLOCAPROC']) ? 'F' : $row['IDLOCAPROC'];

            if($emptyFields) {
                throw new \Exception('Solicitação bloqueada! <br/> Os seguintes parâmetros são obrigatórios: <br/>'.$emptyFields);
            }

            $this->webServiceService->validateCustomizationFiles($nrinsjurluso, $nrcepluso, $cdpais, $sgestado, $cdmunicipio, $idtpijurluso, $nmrazsocluso, $nrorg, $cdlocaluso);
            $isNew = empty($row['__is_new']) ? null : $row['__is_new'];

            $return = $this->webServiceService->saveCustomizationFiles($cdlocaluso, $nmfantluso, $nmrazsocluso, $nrinsjurluso,
                $nrinsestluso, $nrinsmuniluso, $nmcontluso, $nmdeptoluso, $idfaturafilisep, $dsendeluso, $nmbairluso,
                $nrcepluso, $cdpais, $sgestado, $cdmunicipio, $nrteleluso, $nrramalluso, $nrfaxluso, $dsemailcomlu,
                $cdlinpclie, $nrlicencauso, $idmodproc, $idlocaproc, $isNew, $idlusoativ, $idtpijurluso, $nrorg);
            $response->addDataSet(new DataSet("saveCustomizationFiles", $return));
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function removeCustomizationFileByCdCliente(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $licensauso = Utilities::zeroLeftPadding($row['CDLOCALUSO'],10);
            $nrorg = $row['NRORG'];
            $IsActive = $row['IS_ACTIVE'];
            $this->webServiceService->removeCustomizationFile($licensauso, $nrorg, $IsActive);
            $response->addDataSet(new DataSet("customizationFilesActivation", [true]));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findUseLicenseByCdcliente(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $nrorg = Utilities::getValueInFilterDataSourceByName($params, 'NRORG', true);
            $useLicense = $this->webServiceService->findUseLicenseByCdcliente($params, $nrorg);
            $response->addDataSet(new DataSet("findUseLicense", $useLicense));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCountry(Request\Filter $request, Response $response) {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $filters = DevOpsUtilities::createQueryFiltered($conditions);
            $customizationFiles = InstanceProvider::getService()->getCustomizationFiles();
            $country = $customizationFiles->findCountry($filters);
            $response->addDataSet(new DataSet("findCountry", $country));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCity(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $emptyFields = '';
            $sgEstado = Utilities::getInFilterDataSourceByName($params, 'SGESTADO', true);
            $countryId = Utilities::getInFilterDataSourceByName($params, 'CDPAIS', true);
            if(!$sgEstado) {
                $emptyFields.= 'SGESTADO, ';
            }
            if(!$countryId) {
                $emptyFields.= 'CDPAIS, ';
            }
            if($emptyFields) {
                throw new \Exception('Os seguintes filtros são obrigatórios: <br/>'.$emptyFields);
            }
            $filters = DevOpsUtilities::createQueryFiltered($params);
            $sgEstadoFilter = DevOpsUtilities::createQueryFiltered(array($sgEstado),'M');
            $countryIdFilter = DevOpsUtilities::createQueryFiltered(array($countryId),'M');
            $city = $this->webServiceService->findCity($sgEstadoFilter, $countryIdFilter,$filters);
            $response->addDataSet(new DataSet("findCity", $city));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findState(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $emptyFields = '';
            $countryId = Utilities::getInFilterDataSourceByName($params, 'CDPAIS', true);
            if(!$countryId) {
                $emptyFields.= 'CDPAIS, ';
            }
            if($emptyFields) {
                throw new \Exception('Os seguintes filtros são obrigatórios: <br/>'.$emptyFields);
            }
            $filters = DevOpsUtilities::createQueryFiltered($params);
            $countryIdFilter = DevOpsUtilities::createQueryFiltered(array($countryId),'E');
            $state = $this->webServiceService->findState($countryIdFilter, $filters);
            $response->addDataSet(new DataSet("findState", $state));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }
}
