/* Tabela PARAVEND: TABELA DE PARAMETROS DE VENDA*/
/* Descrio: A trigger insere registros na tabela LOGOPERAVND a partir de alteraes na tabela PARAVEND */
/* Objetivo: Gerar um log que vai registrar as alteraes na PARAVEND,
             utilizando a tabela de Logs de Operaes do VND*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_VND_CCUSCLIE' AND
                 TYPE   = 'TR' 	               AND
	              U.UID  = O.UID                 AND
	              U.NAME = USER)
DROP TRIGGER LOG_VND_PARAVEND
GO

CREATE TRIGGER LOG_VND_CCUSCLIE
ON CCUSCLIE
FOR INSERT, UPDATE, DELETE
AS

  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(40);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_ID_COMANDO    VARCHAR(1);

  DECLARE @V_NEW_CDCLIENTE           varchar(21);
  DECLARE @V_NEW_CDCCUSCLIE          varchar(10);
  DECLARE @V_NEW_NMCCUSCLIE          varchar(40);
  DECLARE @V_NEW_DTULTATUCUSC        datetime;
  DECLARE @V_NEW_NRORG				 numeric(15);
  DECLARE @V_NEW_DTINCLUSAO			 date;
  DECLARE @V_NEW_DTULTATU            date;
  DECLARE @V_NEW_NRORGINCLUSAO       double precision;
  DECLARE @V_NEW_CDOPERINCLUSAO      varchar(12);
  DECLARE @V_NEW_NRORGULTATU         double precision;
  DECLARE @V_NEW_CDOPERULTATU        varchar(12);
  DECLARE @V_NEW_IDATIVO			 varchar(1);

  DECLARE @V_OLD_CDCLIENTE           varchar(21);
  DECLARE @V_OLD_CDCCUSCLIE          varchar(10);
  DECLARE @V_OLD_NMCCUSCLIE          varchar(40);
  DECLARE @V_OLD_DTULTATUCUSC        datetime;
  DECLARE @V_OLD_NRORG				 numeric(15);
  DECLARE @V_OLD_DTINCLUSAO			 date;
  DECLARE @V_OLD_DTULTATU            date;
  DECLARE @V_OLD_NRORGINCLUSAO       double precision;
  DECLARE @V_OLD_CDOPERINCLUSAO      varchar(12);
  DECLARE @V_OLD_NRORGULTATU         double precision;
  DECLARE @V_OLD_CDOPERULTATU        varchar(12);
  DECLARE @V_OLD_IDATIVO			 varchar(1);



BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC   = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @P_NMUSUARIO = @V_NMOPERADOR OUTPUT;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, ' ');

   EXEC WEBTUNNING  @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                    @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                    @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                    @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                    @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;

   DECLARE C_CURSOR CURSOR FOR
     SELECT
     'D'   ID_COMANDO,        
	   NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,
           
           CDCLIENTE, CDCCUSCLIE, NMCCUSCLIE, DTULTATUCUSC, NRORG, DTINCLUSAO, 
		   DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO
     FROM
           DELETED
     WHERE     
           CDCLIENTE+CDCCUSCLIE NOT IN (SELECT CDCLIENTE+CDCCUSCLIE FROM INSERTED)
     UNION ALL

     SELECT
     'U'   IDCOMANDO,
           INSERTED.CDCLIENTE, INSERTED.CDCCUSCLIE, INSERTED.NMCCUSCLIE, INSERTED.DTULTATUCUSC, INSERTED.NRORG, INSERTED.DTINCLUSAO, 
		   INSERTED.DTULTATU, INSERTED.NRORGINCLUSAO, INSERTED.CDOPERINCLUSAO, INSERTED.NRORGULTATU, INSERTED.CDOPERULTATU, 
		   INSERTED.IDATIVO,

           DELETED.CDCLIENTE, DELETED.CDCCUSCLIE, DELETED.NMCCUSCLIE, DELETED.DTULTATUCUSC, DELETED.NRORG, DELETED.DTINCLUSAO, 
		   DELETED.DTULTATU, DELETED.NRORGINCLUSAO, DELETED.CDOPERINCLUSAO, DELETED.NRORGULTATU, DELETED.CDOPERULTATU, 
		   DELETED.IDATIVO
     FROM
          INSERTED,
          DELETED
     WHERE     
           DELETED.CDCLIENTE   = INSERTED.CDCLIENTE AND
           DELETED.CDCCUSCLIE = INSERTED.CDCCUSCLIE
     UNION ALL

     SELECT
     'I'   IDCOMANDO,
           INSERTED.CDCLIENTE, INSERTED.CDCCUSCLIE, INSERTED.NMCCUSCLIE, INSERTED.DTULTATUCUSC, INSERTED.NRORG, INSERTED.DTINCLUSAO, 
		   INSERTED.DTULTATU, INSERTED.NRORGINCLUSAO, INSERTED.CDOPERINCLUSAO, INSERTED.NRORGULTATU, INSERTED.CDOPERULTATU, 
		   INSERTED.IDATIVO,


	       NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL
            
     FROM  
           INSERTED
     WHERE 
           CDCLIENTE+CDCCUSCLIE NOT IN (SELECT CDCLIENTE+CDCCUSCLIE FROM DELETED)

     OPEN C_CURSOR;
        FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,

                                      @V_NEW_CDCLIENTE,@V_NEW_CDCCUSCLIE,@V_NEW_NMCCUSCLIE,@V_NEW_DTULTATUCUSC,
                                      @V_NEW_NRORG,@V_NEW_DTINCLUSAO,@V_NEW_DTULTATU,@V_NEW_NRORGINCLUSAO,
                                      @V_NEW_NRORGULTATU,@V_NEW_CDOPERULTATU,@V_NEW_IDATIVO,

                                      @V_OLD_CDCLIENTE,@V_OLD_CDCCUSCLIE,@V_OLD_NMCCUSCLIE,@V_OLD_DTULTATUCUSC,
                                      @V_OLD_NRORG,@V_OLD_DTINCLUSAO,@V_OLD_DTULTATU,@V_OLD_NRORGINCLUSAO,
                                      @V_OLD_NRORGULTATU,@V_OLD_CDOPERULTATU,@V_OLD_IDATIVO


   WHILE (@@FETCH_STATUS = 0) BEGIN

     IF @V_ID_COMANDO= 'D' /*DELEO*/ 
	 BEGIN

	   IF @V_OLD_CDCLIENTE IS NOT NULL BEGIN 
	      SET @V_DESC = ' ' + 'CDCLIENTE ' + @V_OLD_CDCLIENTE;
	   END;
	   IF @V_OLD_CDCCUSCLIE IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' CDCCUSCLIE ' + ISNULL(@V_OLD_CDCCUSCLIE,'' );
	   END;
	   IF @V_OLD_NMCCUSCLIE IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' NMCCUSCLIE ' + ISNULL(@V_OLD_NMCCUSCLIE,'' );
	   END;
	   IF CONVERT(VARCHAR,@V_OLD_DTULTATUCUSC) IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' DTULTATUCUSC ' + CONVERT(VARCHAR,@V_OLD_DTULTATUCUSC);
	   END;
	   IF CONVERT(VARCHAR,@V_OLD_NRORG) IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORG ' + CONVERT(VARCHAR,@V_OLD_NRORG);
	   END;
	   IF CONVERT(VARCHAR,@V_OLD_DTINCLUSAO) IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' DTINCLUSAO ' + CONVERT(VARCHAR,@V_OLD_DTINCLUSAO);
	   END;
	   IF CONVERT(VARCHAR,@V_OLD_DTULTATU) IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' DTULTATU ' + CONVERT(VARCHAR,@V_OLD_DTULTATU);
	   END;
	   IF CONVERT(VARCHAR,@V_OLD_NRORGINCLUSAO) IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORGINCLUSAO ' + CONVERT(VARCHAR, @V_OLD_NRORGINCLUSAO);
	   END;
	   IF @V_OLD_CDOPERINCLUSAO IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' CDOPERINCLUSAO ' + ISNULL(@V_OLD_CDOPERINCLUSAO,'' );
	   END;
	   IF CONVERT(VARCHAR,@V_OLD_NRORGULTATU) IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORGULTATU ' + CONVERT(VARCHAR,@V_OLD_NRORGULTATU);
	   END;
	   IF @V_OLD_CDOPERULTATU IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' CDOPERULTATU ' + ISNULL(@V_OLD_CDOPERULTATU,'' );
	   END;
	   IF @V_OLD_IDATIVO IS NOT NULL BEGIN
	      SET @V_DESC = ISNULL(@V_DESC, '') + ' IDATIVO ' + ISNULL(@V_OLD_IDATIVO,'' );
	   END;

	   SET @V_IDTIPOOPER = 3;
	 END;

        IF @V_ID_COMANDO= 'U' /*UPDATE*/ 
		BEGIN
       
		   IF ISNULL(@V_NEW_CDCLIENTE ,'NULL') <> ISNULL(@V_OLD_CDCLIENTE ,'NULL') BEGIN 
			  SET @V_DESC = 'CDCLIENTE ' + ISNULL(@V_NEW_CDCLIENTE,'' );
		   END;
		   IF ISNULL(@V_NEW_CDCCUSCLIE, 'NULL') <> ISNULL(@V_OLD_CDCCUSCLIE, 'NULL') BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' CDCCUSCLIE ' + ISNULL(@V_OLD_CDCCUSCLIE,'' );
		   END;
		   IF ISNULL(@V_NEW_NMCCUSCLIE ,'NULL') <> ISNULL(@V_OLD_NMCCUSCLIE ,'NULL') BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NMCCUSCLIE ' + ISNULL(@V_NEW_NMCCUSCLIE,'' );
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_DTULTATUCUSC) <> CONVERT(VARCHAR,@V_OLD_DTULTATUCUSC) BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' DTULTATUCUSC ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUCUSC),'');
		   END;
		   IF ISNULL(@V_NEW_NRORG ,'NULL') <> ISNULL(@V_OLD_NRORG ,'NULL') BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORG ' + ISNULL(@V_NEW_NRORG,'' );
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_DTINCLUSAO) <> CONVERT(VARCHAR, @V_OLD_DTINCLUSAO) BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' DTINCLUSAO ' + ISNULL(CONVERT(VARCHAR, @V_NEW_DTINCLUSAO),'' );
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_DTULTATU) <> CONVERT(VARCHAR,@V_OLD_DTULTATU) BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' DTULTATU ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATU), '');
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_NRORGINCLUSAO) <> CONVERT(VARCHAR,@V_OLD_NRORGINCLUSAO) BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORGINCLUSAO ' + ISNULL(CONVERT(VARCHAR, @V_NEW_NRORGINCLUSAO),'');
		   END;
		   IF @V_NEW_CDOPERINCLUSAO <> @V_OLD_CDOPERINCLUSAO BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' CDOPERINCLUSAO ' + ISNULL(@V_NEW_CDOPERINCLUSAO,'' );
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_NRORGULTATU) <> CONVERT(VARCHAR,@V_OLD_NRORGULTATU) BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORGULTATU ' + CONVERT(VARCHAR,@V_NEW_NRORGULTATU);
		   END;
		   IF ISNULL(@V_NEW_CDOPERULTATU, 'NULL') <> ISNULL(@V_OLD_CDOPERULTATU, 'NULL') BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' CDOPERULTATU ' + ISNULL(@V_NEW_CDOPERULTATU,'' );
		   END;
		   IF ISNULL(@V_NEW_IDATIVO, 'NULL') <> ISNULL(@V_OLD_IDATIVO, 'NULL') BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' IDATIVO ' + ISNULL(@V_NEW_IDATIVO,'' );
		   END;

	   
		   SET @V_IDTIPOOPER = 2;
		END;

        IF @V_ID_COMANDO= 'I' /*INSERO*/ 
		BEGIN

		   IF @V_NEW_CDCLIENTE IS NOT NULL BEGIN 
			  SET @V_DESC = ' ' + 'CDCLIENTE ' + @V_NEW_CDCLIENTE;
		   END;
		   IF @V_NEW_CDCCUSCLIE IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' CDCCUSCLIE ' + ISNULL(@V_NEW_CDCCUSCLIE,'' );
		   END;
		   IF @V_NEW_NMCCUSCLIE IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NMCCUSCLIE ' + ISNULL(@V_NEW_NMCCUSCLIE,'' );
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_DTULTATUCUSC) IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' DTULTATUCUSC ' + CONVERT(VARCHAR,@V_NEW_DTULTATUCUSC);
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_NRORG) IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORG ' + CONVERT(VARCHAR,@V_NEW_NRORG);
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_DTINCLUSAO) IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' DTINCLUSAO ' + CONVERT(VARCHAR,@V_NEW_DTINCLUSAO);
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_DTULTATU) IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' DTULTATU ' + CONVERT(VARCHAR,@V_NEW_DTULTATU);
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_NRORGINCLUSAO) IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORGINCLUSAO ' + CONVERT(VARCHAR, @V_NEW_NRORGINCLUSAO);
		   END;
		   IF @V_NEW_CDOPERINCLUSAO IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' CDOPERINCLUSAO ' + ISNULL(@V_NEW_CDOPERINCLUSAO,'' );
		   END;
		   IF CONVERT(VARCHAR,@V_NEW_NRORGULTATU) IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' NRORGULTATU ' + CONVERT(VARCHAR,@V_NEW_NRORGULTATU);
		   END;
		   IF @V_NEW_CDOPERULTATU IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' CDOPERULTATU ' + ISNULL(@V_NEW_CDOPERULTATU,'' );
		   END;
		   IF @V_NEW_IDATIVO IS NOT NULL BEGIN
			  SET @V_DESC = ISNULL(@V_DESC, '') + ' IDATIVO ' + ISNULL(@V_NEW_IDATIVO,'' );
		   END;

			SET @V_IDTIPOOPER = 1;
		END;
        
	IF  (@V_IDTIPOOPER <> '') BEGIN
            IF @V_DESC IS NOT NULL BEGIN
               SET @V_ITPESQ =  ISNULL(@V_NEW_CDCLIENTE + @V_NEW_CDCCUSCLIE,@V_OLD_CDCLIENTE + @V_OLD_CDCCUSCLIE);
   	       SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
               INSERT INTO LOGOPERAVND
      	              (NMTABELAVND, DTOPERACAOVND, NMRESPOPERVND, IDTIPOOPERVND, DSOPERACAOVND,
                       CDPESQITEMVND, DSRDMUSUOPERVND, DSENDUSUOPERVND, DSNMUSUOPERVND, DSMETUSUOPERVND,
                       CDORESPOPERVND, CDFILLOGOPERVND)
               VALUES ('PARAVEND',GETDATE(), ISNULL(@V_NMOPERADOR,' '), @V_IDTIPOOPER, @V_DESC, @V_ITPESQ,
                       @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER,
                       '');
            END;
        END;
	FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,

                                     @V_NEW_CDCLIENTE,@V_NEW_CDCCUSCLIE,@V_NEW_NMCCUSCLIE,@V_NEW_DTULTATUCUSC,
                                      @V_NEW_NRORG,@V_NEW_DTINCLUSAO,@V_NEW_DTULTATU,@V_NEW_NRORGINCLUSAO,
                                      @V_NEW_NRORGULTATU,@V_NEW_CDOPERULTATU,@V_NEW_IDATIVO,

                                      @V_OLD_CDCLIENTE,@V_OLD_CDCCUSCLIE,@V_OLD_NMCCUSCLIE,@V_OLD_DTULTATUCUSC,
                                      @V_OLD_NRORG,@V_OLD_DTINCLUSAO,@V_OLD_DTULTATU,@V_OLD_NRORGINCLUSAO,
                                      @V_OLD_NRORGULTATU,@V_OLD_CDOPERULTATU,@V_OLD_IDATIVO

   SET @V_DESC   = '';
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_VND_PARAVEND','6.45.041';
GO
